---
title: Introduction
---

# Introduction

Bacteriophages, or phages for short, are viruses that infect bacteria and hijack bacterial cellular machinery to reproduce themselves. Phages are extremely abundant entities, and could be responsible for up to 20-40% of bacterial mortality daily (Hampton et al., 2020). Therefore, phage infection constitutes a very strong evolutionary pressure for bacteria.

In response to this evolutionary pressure, bacteria have developed an arsenal of anti-phage defense systems. The term "defense system" here designates either a single gene or a set of genes, which expression provides the bacteria with some level of resistance against phage infection.

# History

The first anti-phage defense system was discovered in the early 1950s by two separate teams of researchers (Luria and Human, 1952 ; Bertani and Wiegle 1952). Luria and Human reported a mysterious phenomenon, where one phage was only capable of infecting a specific bacterial strain once. The progeny phages produced by this first round of infection had lost their ability to infect the same strain again, yet remained able to infect other bacterial strains. For them, this could only mean that "the genotype of the host in which a virus reproduces affects the phenotype of the new virus" (Luria and Human, 1952). A similar phenomenon was shortly after described by Bertani and Wiegle.

Their work was in fact the first report of what would later be named Restriction-Modification ([RM](/list_defense_systems/RM)) system, which is considered to be the first anti-phage defense system discovered.

The sighting of a second defense system occured more than 40 years later, in the late 1980s, when several teams around the world observed arrays containing short, palindromic DNA repeats clustered together on the bacterial genome (Barrangou et al., 2017). Yet, the biological function of these repeats was only elucidated in 2007, when a team of researchers demonstrated that these repeats were part of a new anti-phage defense systems (Barrangou et al., 2007) , known as [CRISPR-Cas system](/list_defense_systems/CRISPR).

Following these two major breakthroughs, knowledge of anti-phage systems remained scarce for some years. Yet, in 2011, Makarova and colleagues revealed that anti-phage systems tend to colocalize on the bacterial genome in defense-islands. This led to a guilt-by-association hypothesis : if a gene or a set of genes is frequently found in bacterial genomes in close proximity to known defense systems, such as RM or CRISPR-Cas systems, then it might constitute a new defense system. This concept had a large role in the discovery of an impressive diversity of defense systems in a very short amount of time. To date, more than 60 defense systems have been described.

## List of known defense systems

To date, more than 60 anti-phage defense systems have been described. An exhaustive list of the systems with experimentally validated anti-phage activity can be found [here](/defense_systems).

## Molecular mechanisms

The molecular mechanisms responsible for the anti-phage activity of defense systems are diverse. Overall, these molecular mechanisms can be divided into 3 categories (Tal and Sorek, 2022):

- **Degrading phage nucleic acids (either DNA or RNA)**

One or a combination of enzymes will degrade phage nucleic acids upon their injection into the bacterial host.

Target nucleic acid recognition and degradation of the target (often through endonuclease activity) are key functions performed by these defense systems. To avoid collateral damage to the bacterial DNA, these functions are accompanied by mechanisms allowing Self versus Non-Self discrimination.

[RM](/list_defense_systems/RM) and [CRISPR-Cas](/list_defense_systems/CRISPR) systems are the main representants of this type of anti-phage systems.

- **Inhibiting nucleic acid synthesis**

After phage nucleic acids are injected, their replication and/or transcription is inhibited.

This can be achieved by the bacteria through the production of small anti-phage molecules (see [Chemical defense](/general_concepts/Chemical_defense)). For instance, [prokaryotic viperins](/list_defense_systems/viperins) produce chain terminators which, once integrated in a nascent nucleic acid, stop its further elongation.

Another possible strategy is the depletion of cell components essential to viral replication. For instance, some enzymes (like dGTPase) deplete the cytosolic pool of deoxynucleotide triphosphates (dNTPs), which are essential building blocks for nucleic acid synthesis.

- **Abortive infection**

Abortive infection can be described as the suicide of a bacteria when infected by a phage. The premature death of the bacterial host prevents the completion of the phage infection cycle, therefore avoiding the production and release of a multitude of newly formed phages. This represents a widespread strategy for anti-phage defense at the community level in bacterial populations.

Abortive infection usually involves a sensor module responsible for detecting phage infection and activating an effector module, which will in turn mediates cell death.

## Impact and applications of defense systems in diverse fields

The study of anti-phage defense systems has had a significant impact on a striking amount of research and industry fields:

- **molecular biology**

The discovery of the first anti-phage system also marked the discovery of restriction enzymes, which are key elements of RM systems. Through their ability to recognize specific nucleic sequences and cleave nucleic acid, restriction enzymes quickly became invaluable tools for molecular biology. A Nobel Prize was awarded in 1978 to Werner Arber, Daniel Nathans and Hamilton O. Smith ["for the discovery of restriction enzymes and their application to problems of molecular genetics."](/https://www.nobelprize.org/prizes/medicine/1978/summary/)

A few decades later, the discovery of CRISPR-Cas systems also created a major genome editing revolution. The Cas nucleases are major components of CRISPR-Cas, and are able to specifically recognize and bind a given nucleic sequence thanks to an RNA guide. This RNA guide can easily be programmed to target any desired sequence, making CRISPR-Cas derived components extremely powerful tools for researchers. A Nobel prize was awarded in 2020 to Emmanuelle Charpentier and Jennifer A. Doudna ["for the development of a method for genome editing"](/https://www.nobelprize.org/prizes/chemistry/2020/summary/).

- **agri-food industries**

- **human health**

## References

Barrangou, R. et al. CRISPR provides acquired resistance against viruses in
prokaryotes. Science 315, 1709–1712 (2007)

Barrangou R, Horvath P. A decade of discovery: CRISPR functions and applications. Nat Microbiol. 2017 Jun 5;2:17092. doi: 10.1038/nmicrobiol.2017.92. PMID: 28581505

BERTANI, G, and J J WEIGLE. “Host controlled variation in bacterial viruses.” Journal of bacteriology vol. 65,2 (1953): 113-21. doi:10.1128/jb.65.2.113-121.1953

Doron S, Melamed S, Ofir G, Leavitt A, Lopatina A, Keren M, Amitai G, Sorek R. Systematic discovery of antiphage defense systems in the microbial pangenome. Science. 2018 Mar 2;359(6379):eaar4120. doi: 10.1126/science.aar4120. Epub 2018 Jan 25. PMID: 29371424; PMCID: PMC6387622.

Gao L, Altae-Tran H, Böhning F, et al. Diverse enzymatic activities mediate antiviral immunity in prokaryotes. Science. 2020;369(6507):1077-1084. doi:10.1126/science.aba0372

Hampton, H. G., Watson, B. N. J. & Fineran, P. C. The arms race between bacteria and their phage foes. Nature 577, 327–336 (2020)

LURIA SE, HUMAN ML. A nonhereditary, host-induced variation of bacterial viruses. J Bacteriol. 1952;64(4):557-569. doi:10.1128/jb.64.4.557-569.1952

Makarova KS, Wolf YI, Snir S, Koonin EV. Defense islands in bacterial and archaeal genomes and prediction of novel defense systems. J Bacteriol. 2011 Nov;193(21):6039-56. doi: 10.1128/JB.05535-11. Epub 2011 Sep 9. PMID: 21908672; PMCID: PMC3194920.

Tal N, Sorek R. SnapShot: Bacterial immunity. Cell. 2022 Feb 3;185(3):578-578.e1. doi: 10.1016/j.cell.2021.12.029. PMID: 35120666.


